---
name: Bug report
about: Create a report to help us improve
title: "[BUG] Title Here"
labels: bug
assignees: HideyoshiNakazone

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment Information:**
 - Python: 
 - Jambo Version: 
 - Pydantic: 

**Additional context**
Add any other context about the problem here.
